%define realname        zstd
%define libmajor        1
%define libname         %mklibname %{realname} %{libmajor}
%define libname_devel   %mklibname %{realname} -d

# aarch64 and armv7hl at least currently segfault
# in ThreadPool test for the pzstd util
%ifarch %{ix86} x86_64
%bcond_without pzstd
%endif

# Something is broken with how Iurt sets up the environment
# for the test suite's run...
%bcond_with check

Name:           zstd
Version:        1.3.8
Release:        %mkrel 1
Summary:        Zstd compression library
Group:          Archiving/Compression
License:        BSD and GPLv2
URL:            https://github.com/facebook/zstd
Source0:        https://github.com/facebook/zstd/archive/v%{version}/%{name}-%{version}.tar.gz
Patch1:         pzstd.1.patch

BuildRequires:  gcc gtest-devel

%description
Zstd, short for Zstandard, is a fast lossless compression algorithm,
targeting real-time compression scenarios at zlib-level compression ratio.

%package -n %{libname}
Summary:        Zstd shared library
Group:          System/Libraries

%description -n %{libname}
Zstandard compression shared library.

%package -n %{libname_devel}
Summary:        Header files for Zstd library
Group:          Development/C
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}
Provides:       lib%{name}-devel = %{version}-%{release}

%description -n %{libname_devel}
Header files for Zstd library.


%prep
%setup -q
find -name .gitignore -delete
%if %{with pzstd}
%patch1 -p1
%endif

%build
%setup_compile_flags
for dir in lib programs; do
  %make_build -C $dir
done
%if %{with pzstd}
%make_build -C contrib/pzstd
%endif

%if %{with check}
%check
make -C tests test-zstd
%if %{with pzstd}
make -C contrib/pzstd test
%endif
%endif

%install
%make_install PREFIX=%{_prefix} LIBDIR=%{_libdir}
# Don't install the static lib
rm %{buildroot}/%{_libdir}/libzstd.a
%if %{with pzstd}
install -D -m755 contrib/pzstd/pzstd %{buildroot}/usr/bin/pzstd
install -D -m644 programs/%{name}.1 %{buildroot}/%{_mandir}/man1/p%{name}.1
%endif

%files
%doc CHANGELOG README.md
%{_bindir}/%{name}
%if %{with pzstd}
%{_bindir}/p%{name}
%{_mandir}/man1/p%{name}.1*
%endif
%{_bindir}/%{name}mt
%{_bindir}/un%{name}
%{_bindir}/%{name}cat
%{_bindir}/%{name}less
%{_bindir}/%{name}grep
%{_mandir}/man1/%{name}.1*
%{_mandir}/man1/un%{name}.1*
%{_mandir}/man1/%{name}cat.1*
%{_mandir}/man1/%{name}less.1*
%{_mandir}/man1/%{name}grep.1*
%license LICENSE

%files -n %{libname}
%{_libdir}/libzstd.so.%{libmajor}{,.*}
%license LICENSE

%files -n %{libname_devel}
%{_includedir}/zbuff.h
%{_includedir}/zdict.h
%{_includedir}/zstd.h
%{_includedir}/zstd_errors.h
%{_libdir}/pkgconfig/libzstd.pc
%{_libdir}/libzstd.so



%changelog
* Thu Aug 29 2019 daviddavid <daviddavid> 1.3.8-1.mga6
+ Revision: 1434956
- new version: 1.3.8, fixes CVE-2019-11922 (mga#25375)
+ tmb <tmb>
- add to mga6 for btrfs-progs 4.14

* Tue Nov 21 2017 tmb <tmb> 1.3.2-1.mga7
+ Revision: 1178202
- fix group
- adapt for Mageia
- import from fedora


* Fri Nov 10 2017 Pádraig Brady <P@draigBrady.com> - 1.3.2-1
- Latest upstream

* Mon Aug 21 2017 Pádraig Brady <P@draigBrady.com> - 1.3.1-1
- Latest upstream

* Thu Aug 03 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.0-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Binutils_Mass_Rebuild

* Thu Jul 27 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.3.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Sun Jul 16 2017 Pádraig Brady <P@draigBrady.com> - 1.3.0-1
- Latest upstream

* Mon May 08 2017 Pádraig Brady <P@draigBrady.com> - 1.2.0-1
- Latest upstream

* Mon Mar 06 2017 Pádraig Brady <P@draigBrady.com> - 1.1.3-1
- Latest upstream

* Sat Feb 11 2017 Fedora Release Engineering <releng@fedoraproject.org> - 1.1.1-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_26_Mass_Rebuild

* Wed Nov 02 2016 Pádraig Brady <pbrady@redhat.com> - 1.1.1-1
- Latest upstream

* Thu Oct 6  2016 Pádraig Brady <pbrady@fb.com> 1.1.0-2
- Add pzstd(1)

* Thu Sep 29 2016 Pádraig Brady <pbrady@fb.com> 1.1.0-1
- New upstream release
- Remove examples and static lib

* Mon Sep 12 2016 Pádraig Brady <pbrady@fb.com> 1.0.0-2
- Adjust various upstream links
- Parameterize various items in spec file

* Mon Sep 5 2016 Pádraig Brady <pbrady@fb.com> 1.0.0-1
- Initial release
